@@ -19,8 +19,7 @@ has http_response => (
 has json => ( is => 'lazy', default => sub { JSON::XS->new } );
 has response            => ( is => 'lazy', builder => '_build_response' );
 has error               => ( is => 'lazy', writer => '_set_error' );
-has _request_obj     => ( is => 'ro' );
-has _parent             => ( is => 'ro' );
+has request_object     => ( is => 'ro' );
 has _response_transform => ( is => 'ro' );
 
 sub success { !shift->error }
@@ -56,11 +55,6 @@ sub _build_response {
 
 sub res { shift->response }
 
-sub retry {
-    my $self = shift;
-    return $self->_parent->http_request($self->_request_obj);
-}
-
 1;
 
 __END__
